@@ -19,20 +19,22 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  ***********************************************************************/
 #include "actions.h"
-#include "debug.h"
 #include "theStream.h"
 
-
+#include <KDebug>
 #include <KIcon>
 #include <KLocale>
 
 #include "videoWindow.h"
 
 Dragon::PlayAction::PlayAction( QObject *receiver, const char *slot, KActionCollection *ac )
-        : KToggleAction( i18n("Play"), ac )
+        : KDualAction( ac )
 {
-    setObjectName( "play" );
-    setIcon( KIcon( "media-playback-start" ) );
+    setObjectName( QLatin1String( "play" ) );
+
+    setInactiveGuiItem( KGuiItem( i18n( "Play" ), KIcon( QLatin1String( "media-playback-start" ) ) ) );
+    setActiveGuiItem( KGuiItem( i18n( "Pause" ), KIcon( QLatin1String( "media-playback-pause" ) ) ) );
+    setAutoToggle( false );
     setShortcut( Qt::Key_Space );
     ac->addAction( objectName(), this );
     connect( this, SIGNAL( triggered( bool ) ), receiver, slot );
@@ -41,38 +43,17 @@ Dragon::PlayAction::PlayAction( QObject *receiver, const char *slot, KActionColl
 void 
 Dragon::PlayAction::setPlaying( bool playing )
 {
-    if( playing )
-    {
-        setIcon( KIcon( "media-playback-pause" ) );
-        setText( i18n("&Pause") );
-    }
-    else
-    {
-        setIcon( KIcon( "media-playback-start" ) );
-        setText( i18n("&Play") );
-    }
+    setActive( playing );
 }
 
-void
-Dragon::PlayAction::setChecked( bool b )
-{
-
-    if( TheStream::hasMedia() && sender() && QByteArray( sender()->metaObject()->className() ) == "KToolBarButton" ) {
-        // clicking play when empty means open PlayMediaDialog, but we have to uncheck the toolbar button
-        // as KDElibs sets that checked automatically..
-        setChecked( false );
-    }
-    else
-        KToggleAction::setChecked( b );
-}
 /////////////////////////////////////////////////////
 ///Codeine::VolumeAction
 ////////////////////////////////////////////////////
 Dragon::VolumeAction::VolumeAction( QObject *receiver, const char *slot, KActionCollection *ac )
         : KToggleAction( i18nc( "Volume of sound output", "Volume"), ac )
 {
-    setObjectName( "volume" );
-    setIcon( KIcon( "player-volume" ) );
+    setObjectName( QLatin1String( "volume" ) );
+    setIcon( KIcon( QLatin1String(  "player-volume" ) ) );
     setShortcut( Qt::Key_V );
     ac->addAction( objectName(), this );
     connect( this, SIGNAL( triggered( bool ) ), receiver, slot );
@@ -83,9 +64,9 @@ void
 Dragon::VolumeAction::mutedChanged( bool mute )
 {
     if( mute )
-        setIcon( KIcon( "player-volume-muted" ) );
+        setIcon( KIcon( QLatin1String(  "player-volume-muted" ) ) );
     else
-        setIcon( KIcon( "player-volume" ) );
+        setIcon( KIcon( QLatin1String(  "player-volume" ) ) );
 }
 
 #include "actions.moc"
