@@ -30,7 +30,6 @@
 #include <kactionmenu.h>
 #include <kconfiggroup.h>
 
-#include <config.h>
 #include <config-juk.h>
 
 #include <QObject>
@@ -69,10 +68,11 @@ PlaylistCollection *PlaylistCollection::m_instance = 0;
 // public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistCollection::PlaylistCollection(QStackedWidget *playlistStack) :
+PlaylistCollection::PlaylistCollection(PlayerManager *player, QStackedWidget *playlistStack) :
     m_playlistStack(playlistStack),
     m_historyPlaylist(0),
     m_upcomingPlaylist(0),
+    m_playerManager(player),
     m_importPlaylists(true),
     m_searchEnabled(true),
     m_playing(false),
@@ -322,7 +322,7 @@ void PlaylistCollection::open(const QStringList &l)
 
     bool justPlaylists = true;
 
-    for(QStringList::ConstIterator it = l.constBegin(); it != l.constEnd() && justPlaylists; ++it)
+    for(QStringList::ConstIterator it = files.constBegin(); it != files.constEnd() && justPlaylists; ++it)
         justPlaylists = !MediaFiles::isPlaylistFile(*it);
 
     if(visiblePlaylist() == CollectionList::instance() || justPlaylists ||
@@ -351,7 +351,6 @@ void PlaylistCollection::open(const QString &playlist, const QStringList &files)
 
 void PlaylistCollection::addFolder()
 {
-    kDebug(65432) ;
     DirectoryList l(m_folderList, m_importPlaylists, JuK::JuKInstance());
     DirectoryList::Result result = l.exec();
 
@@ -362,18 +361,14 @@ void PlaylistCollection::addFolder()
         const bool reload = m_importPlaylists != result.addPlaylists;
         m_importPlaylists = result.addPlaylists;
 
-        for(QStringList::const_iterator it = result.addedDirs.constBegin();
-            it != result.addedDirs.constEnd(); it++)
-        {
-            m_dirLister.openUrl(KUrl::fromPath(*it), KDirLister::Keep);
-            m_folderList.append(*it);
+        foreach(const QString &dir, result.addedDirs) {
+            m_dirLister.openUrl(KUrl::fromPath(dir), KDirLister::Keep);
+            m_folderList.append(dir);
         }
 
-        for(QStringList::const_iterator it = result.removedDirs.constBegin();
-            it !=  result.removedDirs.constEnd(); it++)
-        {
-            m_dirLister.stop(KUrl::fromPath(*it));
-            m_folderList.removeAll(*it);
+        foreach(const QString &dir, result.removedDirs) {
+            m_dirLister.stop(KUrl::fromPath(dir));
+            m_folderList.removeAll(dir);
         }
 
         if(reload)
@@ -562,6 +557,9 @@ void PlaylistCollection::setHistoryPlaylistEnabled(bool enable)
         m_historyPlaylist = new HistoryPlaylist(this);
         m_historyPlaylist->setName(i18n("History"));
         setupPlaylist(m_historyPlaylist, "view-history");
+
+        QObject::connect(m_playerManager, SIGNAL(signalItemChanged(FileHandle)),
+                historyPlaylist(), SLOT(appendProposedItem(FileHandle)));
     }
     else {
         delete m_historyPlaylist;
@@ -821,8 +819,8 @@ void PlaylistCollection::readConfig()
     m_importPlaylists  = config.readEntry("ImportPlaylists", true);
     m_folderList       = config.readEntry("DirectoryList", QStringList());
 
-    for(QStringList::ConstIterator it = m_folderList.constBegin(); it != m_folderList.constEnd(); ++it)
-        m_dirLister.openUrl(*it, KDirLister::Keep);
+    foreach(const QString &folder, m_folderList)
+        m_dirLister.openUrl(folder, KDirLister::Keep);
 }
 
 void PlaylistCollection::saveConfig()
@@ -843,7 +841,7 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
     QObject(0),
     m_collection(collection)
 {
-    setObjectName("ActionHandler");
+    setObjectName( QLatin1String("ActionHandler" ));
 
     KActionMenu *menu;
 
